@@ -1,6 +1,8 @@
 package Editor;
 
 use Qt;
+use QEvent;
+use QFileDialog;
 use QMenuBar;
 use QMultiLineEdit;
 use QPopupMenu;
@@ -14,7 +16,7 @@ sub new {
     my $self = shift->SUPER::new(@_);
 
     my $m = new QMenuBar($self, 'menu');
-    my $file = new QPopupMenu->setImmortal;
+    my $file = new QPopupMenu->immortal;
     $m->insertItem('&File', $file);
 
     $file->insertItem('New', $self, 'create()', $ALT+$Key{N});
@@ -58,8 +60,10 @@ sub loadFile {
     $e->setAutoUpdate(0);
     $e->clear();
 
-    $e->append($_) while defined($_ = <FILE>);
-
+    while(<FILE>) {
+	chomp;
+	$e->append($_);
+    }
     close(FILE);
 
     $e->setAutoUpdate(1);
