@@ -12,15 +12,8 @@
 
 #undef bool
 #include "qpixmap.h"
-#include "pbitmap.h"
-#include "pimage.h"
-#include "prect.h"
-#include "psize.h"
-#include "pwmatrix.h"
 #include "pqt.h"
 
-typedef QPixmap::ColorMode QPixmap__ColorMode;
-
 class PPixmap : public QPixmap {
 public:
     PPixmap() {}
@@ -34,4 +27,6 @@ public:
     PPixmap(const QImage &image) { *(QPixmap *)this = image; }
 };
 
+typedef QPixmap::ColorMode QPixmap__ColorMode;
+
 #endif  // PPIXMAP_H
